/* downloader.c generated by valac 0.23.3.6-62e8, the Vala compiler
 * generated from downloader.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <libsoup/soup.h>
#include <osinfo/osinfo.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_DOWNLOAD (boxes_download_get_type ())
#define BOXES_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownload))
#define BOXES_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))
#define BOXES_IS_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOAD))
#define BOXES_IS_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOAD))
#define BOXES_DOWNLOAD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))

typedef struct _BoxesDownload BoxesDownload;
typedef struct _BoxesDownloadClass BoxesDownloadClass;
typedef struct _BoxesDownloadPrivate BoxesDownloadPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _BoxesParamSpecDownload BoxesParamSpecDownload;

#define BOXES_TYPE_DOWNLOADER (boxes_downloader_get_type ())
#define BOXES_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloader))
#define BOXES_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))
#define BOXES_IS_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOADER))
#define BOXES_IS_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOADER))
#define BOXES_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))

typedef struct _BoxesDownloader BoxesDownloader;
typedef struct _BoxesDownloaderClass BoxesDownloaderClass;
typedef struct _BoxesDownloaderPrivate BoxesDownloaderPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _boxes_download_unref0(var) ((var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesDownloaderDownloadData BoxesDownloaderDownloadData;
typedef struct _Block74Data Block74Data;
typedef struct _BoxesDownloaderDownloadFromHttpData BoxesDownloaderDownloadFromHttpData;
typedef struct _BoxesDownloaderFetchOsLogoData BoxesDownloaderFetchOsLogoData;
typedef struct _Block75Data Block75Data;
typedef struct _BoxesDownloaderAwaitDownloadData BoxesDownloaderAwaitDownloadData;

struct _BoxesDownload {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesDownloadPrivate * priv;
	gchar* uri;
	GFile* cached_file;
	BoxesActivityProgress* progress;
};

struct _BoxesDownloadClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesDownload *self);
};

struct _BoxesParamSpecDownload {
	GParamSpec parent_instance;
};

struct _BoxesDownloader {
	GObject parent_instance;
	BoxesDownloaderPrivate * priv;
};

struct _BoxesDownloaderClass {
	GObjectClass parent_class;
};

struct _BoxesDownloaderPrivate {
	SoupSession* session;
	GHashTable* downloads;
};

struct _BoxesDownloaderDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	GFile* remote_file;
	gchar** cached_paths;
	gint cached_paths_length1;
	BoxesActivityProgress* progress;
	GFile* result;
	gchar* uri;
	GFile* _tmp0_;
	gchar* _tmp1_;
	BoxesDownload* download;
	GHashTable* _tmp2_;
	const gchar* _tmp3_;
	gconstpointer _tmp4_;
	BoxesDownload* _tmp5_;
	gchar* cached_path;
	gchar** _tmp6_;
	gint _tmp6__length1;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	BoxesDownload* _tmp9_;
	GFile* _tmp10_;
	BoxesDownload* _tmp11_;
	const gchar* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	GFile* _tmp14_;
	GFile* _tmp15_;
	GFile* cached_file;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar** path_collection;
	gint path_collection_length1;
	gint _path_collection_size_;
	gint path_it;
	gchar* _tmp17_;
	gchar* path;
	const gchar* _tmp18_;
	GFile* _tmp19_;
	GFile* _tmp20_;
	gboolean _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	GFile* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	GFile* _tmp28_;
	BoxesActivityProgress* _tmp29_;
	BoxesDownload* _tmp30_;
	GHashTable* _tmp31_;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	BoxesDownload* _tmp34_;
	BoxesDownload* _tmp35_;
	gboolean _tmp36_;
	GFile* _tmp37_;
	gboolean _tmp38_;
	GFile* _tmp39_;
	gboolean _tmp40_;
	BoxesDownload* _tmp41_;
	GFile* _tmp42_;
	GFile* _tmp43_;
	BoxesActivityProgress* _tmp44_;
	GError* _error_;
	BoxesDownload* _tmp45_;
	GError* _tmp46_;
	GError* _tmp47_;
	GError* _tmp48_;
	GHashTable* _tmp49_;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	const gchar* _tmp52_;
	BoxesDownload* _tmp53_;
	GError * _inner_error_;
};

struct _Block74Data {
	int _ref_count_;
	BoxesDownloader* self;
	SoupMessage* msg;
	gint64 total_num_bytes;
	gint64 current_num_bytes;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderDownloadFromHttpData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	BoxesDownload* download;
	Block74Data* _data74_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	const gchar* _tmp2_;
	SoupMessage* _tmp3_;
	SoupAddress* address;
	SoupMessage* _tmp4_;
	SoupAddress* _tmp5_;
	SoupAddress* _tmp6_;
	GNetworkAddress* connectable;
	SoupAddress* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	SoupAddress* _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
	GNetworkAddress* _tmp13_;
	GNetworkMonitor* network_monitor;
	GNetworkMonitor* _tmp14_;
	GNetworkMonitor* _tmp15_;
	gboolean _tmp16_;
	GNetworkMonitor* _tmp17_;
	GNetworkAddress* _tmp18_;
	gboolean _tmp19_;
	SoupAddress* _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	SoupAddress* _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
	GError* _tmp26_;
	SoupMessage* _tmp27_;
	SoupMessage* _tmp28_;
	SoupSession* _tmp29_;
	SoupMessage* _tmp30_;
	SoupMessage* _tmp31_;
	SoupMessage* _tmp32_;
	guint _tmp33_;
	guint _tmp34_;
	SoupMessage* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	GError* _tmp39_;
	GError* _tmp40_;
	BoxesDownload* _tmp41_;
	GFile* _tmp42_;
	SoupMessage* _tmp43_;
	SoupMessageBody* _tmp44_;
	guint8* _tmp45_;
	gint _tmp45__length1;
	GError * _inner_error_;
};

struct _BoxesDownloaderFetchOsLogoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GtkImage* image;
	OsinfoOs* os;
	gint size;
	gchar* logo_url;
	OsinfoOs* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	OsinfoOs* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GFile* remote_file;
	const gchar* _tmp7_;
	GFile* _tmp8_;
	gchar* system_cached_path;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* cached_path;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar** cached_paths;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar** _tmp21_;
	gint cached_paths_length1;
	gint _cached_paths_size_;
	const gchar* _tmp22_;
	gchar** _tmp23_;
	gint _tmp23__length1;
	const gchar* _tmp24_;
	gchar* _tmp25_;
	GFile* cached_file;
	BoxesDownloader* _tmp26_;
	BoxesDownloader* _tmp27_;
	GFile* _tmp28_;
	gchar** _tmp29_;
	gint _tmp29__length1;
	BoxesActivityProgress* _tmp30_;
	BoxesActivityProgress* _tmp31_;
	GFile* _tmp32_;
	GFile* _tmp33_;
	GdkPixbuf* pixbuf;
	GFile* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	GdkPixbuf* _tmp39_;
	GdkPixbuf* _tmp40_;
	GtkImage* _tmp41_;
	GdkPixbuf* _tmp42_;
	GError* _error_;
	const gchar* _tmp43_;
	GError* _tmp44_;
	const gchar* _tmp45_;
	GError * _inner_error_;
};

struct _Block75Data {
	int _ref_count_;
	BoxesDownloader* self;
	GFile* downloaded_file;
	GError* download_error;
	GSourceFunc callback;
	gpointer callback_target;
	GDestroyNotify callback_target_destroy_notify;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderAwaitDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	BoxesDownload* download;
	gchar* cached_path;
	BoxesActivityProgress* progress;
	GFile* result;
	Block75Data* _data75_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesActivityProgress* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	gulong downloaded_id;
	gulong _tmp4_;
	gulong downloaded_failed_id;
	gulong _tmp5_;
	BoxesDownload* _tmp6_;
	const gchar* _tmp7_;
	BoxesDownload* _tmp8_;
	const gchar* _tmp9_;
	GError* _tmp10_;
	GFile* cached_file;
	gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	GFile* _tmp16_;
	GFile* _tmp17_;
	GFile* _tmp18_;
	GError * _inner_error_;
};


static gpointer boxes_download_parent_class = NULL;
static gpointer boxes_downloader_parent_class = NULL;
static BoxesDownloader* boxes_downloader_downloader;
static BoxesDownloader* boxes_downloader_downloader = NULL;

gpointer boxes_download_ref (gpointer instance);
void boxes_download_unref (gpointer instance);
GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_download (GValue* value, gpointer v_object);
void boxes_value_take_download (GValue* value, gpointer v_object);
gpointer boxes_value_get_download (const GValue* value);
GType boxes_download_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_DOWNLOAD_DUMMY_PROPERTY
};
BoxesDownload* boxes_download_new (const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress);
BoxesDownload* boxes_download_construct (GType object_type, const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress);
static void boxes_download_finalize (BoxesDownload* obj);
GType boxes_downloader_get_type (void) G_GNUC_CONST;
#define BOXES_DOWNLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DOWNLOADER, BoxesDownloaderPrivate))
enum  {
	BOXES_DOWNLOADER_DUMMY_PROPERTY
};
BoxesDownloader* boxes_downloader_get_instance (void);
static BoxesDownloader* boxes_downloader_new (void);
static BoxesDownloader* boxes_downloader_construct (GType object_type);
static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os);
static void _g_free0_ (gpointer var);
static void _boxes_download_unref0_ (gpointer var);
static void boxes_downloader_download_data_free (gpointer _data);
void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_);
static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
void boxes_copy_file (GFile* src_file, GFile* dest_file, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_from_http_data_free (gpointer _data);
static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda45_ (Block74Data* _data74_);
static void ___lambda45__soup_message_got_headers (SoupMessage* _sender, gpointer self);
static void __lambda46_ (Block74Data* _data74_, SoupMessage* msg, SoupBuffer* chunk);
static void ___lambda46__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self);
static void __lambda47_ (Block74Data* _data74_, SoupSession* session, SoupMessage* msg);
static void ___lambda47__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self);
static void boxes_downloader_fetch_os_logo_data_free (gpointer _data);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_);
static void _vala_array_add19 (gchar*** array, int* length, int* size, gchar* value);
static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_await_download_data_free (gpointer _data);
static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_);
static Block75Data* block75_data_ref (Block75Data* _data75_);
static void block75_data_unref (void * _userdata_);
static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self);
static void __lambda43_ (Block75Data* _data75_, BoxesDownloader* downloader, BoxesDownload* downloaded);
static void ___lambda43__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self);
static void __lambda44_ (Block75Data* _data75_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_);
static void ___lambda44__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self);
static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void boxes_downloader_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? g_object_ref (self) : NULL;
#line 434 "downloader.c"
}


BoxesDownload* boxes_download_construct (GType object_type, const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress) {
	BoxesDownload* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (cached_file != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (progress != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = (BoxesDownload*) g_type_create_instance (object_type);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = uri;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->uri = _tmp1_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = cached_file;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->cached_file = _tmp3_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = progress;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->progress = _tmp5_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self;
#line 480 "downloader.c"
}


BoxesDownload* boxes_download_new (const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return boxes_download_construct (BOXES_TYPE_DOWNLOAD, uri, cached_file, progress);
#line 487 "downloader.c"
}


static void boxes_value_download_init (GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	value->data[0].v_pointer = NULL;
#line 494 "downloader.c"
}


static void boxes_value_download_free_value (GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (value->data[0].v_pointer);
#line 503 "downloader.c"
	}
}


static void boxes_value_download_copy_value (const GValue* src_value, GValue* dest_value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (src_value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = boxes_download_ref (src_value->data[0].v_pointer);
#line 513 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = NULL;
#line 517 "downloader.c"
	}
}


static gpointer boxes_value_download_peek_pointer (const GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 525 "downloader.c"
}


static gchar* boxes_value_download_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (collect_values[0].v_pointer) {
#line 532 "downloader.c"
		BoxesDownload* object;
		object = collect_values[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (object->parent_instance.g_class == NULL) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 539 "downloader.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 543 "downloader.c"
		}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = boxes_download_ref (object);
#line 547 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 551 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return NULL;
#line 555 "downloader.c"
}


static gchar* boxes_value_download_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesDownload** object_p;
	object_p = collect_values[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!object_p) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 566 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = NULL;
#line 572 "downloader.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = value->data[0].v_pointer;
#line 576 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = boxes_download_ref (value->data[0].v_pointer);
#line 580 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return NULL;
#line 584 "downloader.c"
}


GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecDownload* spec;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return G_PARAM_SPEC (spec);
#line 598 "downloader.c"
}


gpointer boxes_value_get_download (const GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 607 "downloader.c"
}


void boxes_value_set_download (GValue* value, gpointer v_object) {
	BoxesDownload* old;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_ref (value->data[0].v_pointer);
#line 627 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 631 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 637 "downloader.c"
	}
}


void boxes_value_take_download (GValue* value, gpointer v_object) {
	BoxesDownload* old;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 656 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 660 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 666 "downloader.c"
	}
}


static void boxes_download_class_init (BoxesDownloadClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_download_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	BOXES_DOWNLOAD_CLASS (klass)->finalize = boxes_download_finalize;
#line 676 "downloader.c"
}


static void boxes_download_instance_init (BoxesDownload * self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->ref_count = 1;
#line 683 "downloader.c"
}


static void boxes_download_finalize (BoxesDownload* obj) {
	BoxesDownload * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOAD, BoxesDownload);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 697 "downloader.c"
}


GType boxes_download_get_type (void) {
	static volatile gsize boxes_download_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_download_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_download_init, boxes_value_download_free_value, boxes_value_download_copy_value, boxes_value_download_peek_pointer, "p", boxes_value_download_collect_value, "p", boxes_value_download_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloadClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_download_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownload), 0, (GInstanceInitFunc) boxes_download_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_download_type_id;
		boxes_download_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesDownload", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_download_type_id__volatile, boxes_download_type_id);
	}
	return boxes_download_type_id__volatile;
}


gpointer boxes_download_ref (gpointer instance) {
	BoxesDownload* self;
	self = instance;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&self->ref_count);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return instance;
#line 722 "downloader.c"
}


void boxes_download_unref (gpointer instance) {
	BoxesDownload* self;
	self = instance;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		BOXES_DOWNLOAD_GET_CLASS (self)->finalize (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 735 "downloader.c"
	}
}


BoxesDownloader* boxes_downloader_get_instance (void) {
	BoxesDownloader* result = NULL;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownloader* _tmp2_ = NULL;
	BoxesDownloader* _tmp3_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = boxes_downloader_downloader;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_tmp0_ == NULL) {
#line 749 "downloader.c"
		BoxesDownloader* _tmp1_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp1_ = boxes_downloader_new ();
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (boxes_downloader_downloader);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_downloader = _tmp1_;
#line 757 "downloader.c"
	}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = boxes_downloader_downloader;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _tmp3_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 767 "downloader.c"
}


static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os) {
	gchar* result = NULL;
	OsinfoOs* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* logo_url = NULL;
	OsinfoProductList* derived = NULL;
	OsinfoOs* _tmp7_ = NULL;
	OsinfoProductList* _tmp8_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = os;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp0_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_tmp2_ != NULL) {
#line 790 "downloader.c"
		OsinfoOs* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp3_ = os;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp4_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp3_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp5_ = _tmp4_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		result = _tmp6_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return result;
#line 807 "downloader.c"
	}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	logo_url = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp7_ = os;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp8_ = osinfo_product_get_related ((OsinfoProduct*) _tmp7_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	derived = _tmp8_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	while (TRUE) {
#line 819 "downloader.c"
		gboolean _tmp9_ = FALSE;
		OsinfoProductList* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		OsinfoOs* parent = NULL;
		OsinfoProductList* _tmp13_ = NULL;
		OsinfoEntity* _tmp14_ = NULL;
		OsinfoOs* _tmp15_ = NULL;
		OsinfoOs* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp10_ = derived;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp11_ = osinfo_list_get_length ((OsinfoList*) _tmp10_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_tmp11_ > 0) {
#line 836 "downloader.c"
			const gchar* _tmp12_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp12_ = logo_url;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp9_ = _tmp12_ == NULL;
#line 842 "downloader.c"
		} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp9_ = FALSE;
#line 846 "downloader.c"
		}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (!_tmp9_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			break;
#line 852 "downloader.c"
		}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp13_ = derived;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp14_ = osinfo_list_get_nth ((OsinfoList*) _tmp13_, 0);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp14_) : NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		parent = _tmp15_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp16_ = parent;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp17_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp16_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp18_ = _tmp17_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_tmp18_ != NULL) {
#line 870 "downloader.c"
			OsinfoOs* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp19_ = parent;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp20_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp19_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp21_ = _tmp20_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp22_ = g_strdup (_tmp21_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (logo_url);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			logo_url = _tmp22_;
#line 887 "downloader.c"
		} else {
			OsinfoOs* _tmp23_ = NULL;
			OsinfoProductList* _tmp24_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp23_ = parent;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp24_ = osinfo_product_get_related ((OsinfoProduct*) _tmp23_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (derived);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			derived = _tmp24_;
#line 899 "downloader.c"
		}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (parent);
#line 903 "downloader.c"
	}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = logo_url;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (derived);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 911 "downloader.c"
}


static void _g_free0_ (gpointer var) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	var = (g_free (var), NULL);
#line 918 "downloader.c"
}


static void _boxes_download_unref0_ (gpointer var) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL));
#line 925 "downloader.c"
}


static BoxesDownloader* boxes_downloader_construct (GType object_type) {
	BoxesDownloader * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	SoupSession* _tmp3_ = NULL;
	SoupSession* _tmp4_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = (BoxesDownloader*) g_object_new (object_type, NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = g_str_hash;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_str_equal;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _boxes_download_unref0_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv->downloads = _tmp2_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = soup_session_new ();
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv->session = _tmp3_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = self->priv->session;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_session_add_feature_by_type (_tmp4_, soup_proxy_resolver_default_get_type ());
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self;
#line 960 "downloader.c"
}


static BoxesDownloader* boxes_downloader_new (void) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return boxes_downloader_construct (BOXES_TYPE_DOWNLOADER);
#line 967 "downloader.c"
}


static void boxes_downloader_download_data_free (gpointer _data) {
	BoxesDownloaderDownloadData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadData, _data_);
#line 984 "downloader.c"
}


void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_download_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = remote_file;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_paths;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3__length1 = cached_paths_length1;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = _tmp3__length1;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = progress;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp5_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1033 "downloader.c"
}


GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderDownloadData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return NULL;
#line 1044 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 1054 "downloader.c"
}


/**
     * Downloads the given file.
     *
     * @param remote_file The remote file to download.
     * @param cached_paths Array of cache directories. The file will be saved in the directory the
     *                     first element points to.
     * @param progress The ActivityProgress object to report progress to.
     *
     * @return A file handle to the (now) local file.
     */
static gpointer _boxes_download_ref0 (gpointer self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? boxes_download_ref (self) : NULL;
#line 1071 "downloader.c"
}


static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1085 "downloader.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? g_error_copy (self) : NULL;
#line 1092 "downloader.c"
}


static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 1101 "downloader.c"
		goto _state_0;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 1105 "downloader.c"
		goto _state_1;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 1109 "downloader.c"
		goto _state_2;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 3:
#line 1113 "downloader.c"
		goto _state_3;
		default:
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 1118 "downloader.c"
	}
	_state_0:
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->remote_file;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = g_file_get_uri (_data_->_tmp0_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->uri = _data_->_tmp1_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->self->priv->downloads;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->uri;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_hash_table_lookup (_data_->_tmp2_, _data_->_tmp3_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _boxes_download_ref0 ((BoxesDownload*) _data_->_tmp4_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp5_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6__length1 = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->cached_paths;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6__length1 = _data_->cached_paths_length1;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_[0];
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_strdup (_data_->_tmp7_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp8_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->download;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp9_ != NULL) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = _data_->download;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = _data_->cached_path;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = _data_->progress;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_await_download (_data_->self, _data_->_tmp11_, _data_->_tmp12_, _data_->_tmp13_, boxes_downloader_download_ready, _data_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1191 "downloader.c"
		_state_1:
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = boxes_downloader_await_download_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _data_->_tmp14_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_inner_error_ != NULL) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_error_free (_data_->_inner_error_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->cached_path);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_boxes_download_unref0 (_data_->download);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->uri);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_state_ == 0) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1215 "downloader.c"
			} else {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1219 "downloader.c"
			}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1225 "downloader.c"
		}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->_tmp10_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->result = _data_->_tmp15_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1247 "downloader.c"
		} else {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1251 "downloader.c"
		}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1257 "downloader.c"
	}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16__length1 = 0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->cached_paths;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16__length1 = _data_->cached_paths_length1;
#line 1267 "downloader.c"
	{
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection_length1 = 0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_path_collection_size_ = 0;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection = _data_->_tmp16_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection_length1 = _data_->_tmp16__length1;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		for (_data_->path_it = 0; _data_->path_it < _data_->_tmp16__length1; _data_->path_it = _data_->path_it + 1) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp17_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp17_ = g_strdup (_data_->path_collection[_data_->path_it]);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->path = _data_->_tmp17_;
#line 1285 "downloader.c"
			{
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp18_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp18_ = _data_->path;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp19_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp19_ = g_file_new_for_path (_data_->_tmp18_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_g_object_unref0 (_data_->cached_file);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->cached_file = _data_->_tmp19_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp20_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp20_ = _data_->cached_file;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp21_ = FALSE;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp21_ = g_file_query_exists (_data_->_tmp20_, NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				if (_data_->_tmp21_) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp22_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp22_ = _data_->uri;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp23_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp23_ = _data_->path;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					g_debug ("downloader.vala:82: '%s' already available locally at '%s'. Not downlo" \
"ading.", _data_->_tmp22_, _data_->_tmp23_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->result = _data_->cached_file;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->path);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->cached_path);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_boxes_download_unref0 (_data_->download);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->uri);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					if (_data_->_state_ == 0) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
						g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1333 "downloader.c"
					} else {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
						g_simple_async_result_complete (_data_->_async_result);
#line 1337 "downloader.c"
					}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					g_object_unref (_data_->_async_result);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					return FALSE;
#line 1343 "downloader.c"
				}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_g_free0 (_data_->path);
#line 1347 "downloader.c"
			}
		}
	}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp24_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp24_ = _data_->cached_path;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp25_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp25_ = g_file_new_for_path (_data_->_tmp24_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_file = _data_->_tmp25_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp26_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp26_ = _data_->uri;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:88: Downloading '%s'...", _data_->_tmp26_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = _data_->uri;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = _data_->cached_file;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->progress;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = boxes_download_new (_data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp30_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = _data_->self->priv->downloads;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->uri;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = g_strdup (_data_->_tmp32_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = _data_->download;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = _boxes_download_ref0 (_data_->_tmp34_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_hash_table_insert (_data_->_tmp31_, _data_->_tmp33_, _data_->_tmp35_);
#line 1411 "downloader.c"
	{
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->remote_file;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = FALSE;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = g_file_has_uri_scheme (_data_->_tmp37_, "http");
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp38_) {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp36_ = TRUE;
#line 1425 "downloader.c"
		} else {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp39_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp39_ = _data_->remote_file;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp40_ = FALSE;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp40_ = g_file_has_uri_scheme (_data_->_tmp39_, "https");
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp36_ = _data_->_tmp40_;
#line 1437 "downloader.c"
		}
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp36_) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp41_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp41_ = _data_->download;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 2;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http (_data_->self, _data_->_tmp41_, boxes_downloader_download_ready, _data_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1451 "downloader.c"
			_state_2:
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_inner_error_ != NULL) {
#line 1457 "downloader.c"
				goto __catch119_g_error;
			}
		} else {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp42_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp42_ = _data_->remote_file;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp43_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp43_ = _data_->cached_file;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp44_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp44_ = _data_->progress;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 3;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_copy_file (_data_->_tmp42_, _data_->_tmp43_, _data_->_tmp44_, NULL, boxes_downloader_download_ready, _data_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1479 "downloader.c"
			_state_3:
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_copy_file_finish (_data_->_res_, &_data_->_inner_error_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_inner_error_ != NULL) {
#line 1485 "downloader.c"
				goto __catch119_g_error;
			}
		}
	}
	goto __finally119;
	__catch119_g_error:
	{
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = _data_->download;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp46_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp46_ = _data_->_error_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_signal_emit_by_name (_data_->self, "download-failed", _data_->_tmp45_, _data_->_tmp46_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = _data_->_error_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = _g_error_copy0 (_data_->_tmp47_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp48_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 1519 "downloader.c"
		goto __finally119;
	}
	__finally119:
	{
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp49_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp49_ = _data_->self->priv->downloads;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp50_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp50_ = _data_->uri;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_hash_table_remove (_data_->_tmp49_, _data_->_tmp50_);
#line 1534 "downloader.c"
	}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_inner_error_ != NULL) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1554 "downloader.c"
		} else {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1558 "downloader.c"
		}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1564 "downloader.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp51_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp51_ = _data_->uri;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp52_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp52_ = _data_->cached_path;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:105: Downloaded '%s' and its now locally available at " \
"'%s'.", _data_->_tmp51_, _data_->_tmp52_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp53_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp53_ = _data_->download;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_emit_by_name (_data_->self, "downloaded", _data_->_tmp53_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1594 "downloader.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1598 "downloader.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1616 "downloader.c"
	} else {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1620 "downloader.c"
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 1626 "downloader.c"
}


static void boxes_downloader_download_from_http_data_free (gpointer _data) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadFromHttpData, _data_);
#line 1637 "downloader.c"
}


static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownload* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadFromHttpData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_download_from_http);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_download_from_http_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1666 "downloader.c"
}


static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 1676 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1680 "downloader.c"
}


static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return _data74_;
#line 1689 "downloader.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 1698 "downloader.c"
		BoxesDownloader* self;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		self = _data74_->self;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data74_->msg);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data74_->download);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_slice_free (Block74Data, _data74_);
#line 1710 "downloader.c"
	}
}


static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1725 "downloader.c"
}


static void __lambda45_ (Block74Data* _data74_) {
	BoxesDownloader* self;
	SoupMessage* _tmp0_ = NULL;
	SoupMessageHeaders* _tmp1_ = NULL;
	gint64 _tmp2_ = 0LL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data74_->self;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data74_->msg;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->response_headers;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = soup_message_headers_get_content_length (_tmp1_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data74_->total_num_bytes = _tmp2_;
#line 1744 "downloader.c"
}


static void ___lambda45__soup_message_got_headers (SoupMessage* _sender, gpointer self) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda45_ (self);
#line 1751 "downloader.c"
}


static void __lambda46_ (Block74Data* _data74_, SoupMessage* msg, SoupBuffer* chunk) {
	BoxesDownloader* self;
	gint64 _tmp0_ = 0LL;
	gint64 _tmp1_ = 0LL;
	SoupBuffer* _tmp2_ = NULL;
	gsize _tmp3_ = 0UL;
	BoxesDownload* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
	gint64 _tmp6_ = 0LL;
	gint64 _tmp7_ = 0LL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data74_->self;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (chunk != NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data74_->total_num_bytes;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_tmp0_ <= ((gint64) 0)) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 1777 "downloader.c"
	}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _data74_->current_num_bytes;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = chunk;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->length;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data74_->current_num_bytes = _tmp1_ + _tmp3_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = _data74_->download;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _tmp4_->progress;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = _data74_->current_num_bytes;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp7_ = _data74_->total_num_bytes;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_tmp5_, ((gdouble) _tmp6_) / _tmp7_);
#line 1797 "downloader.c"
}


static void ___lambda46__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self) {
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda46_ (self, _sender, chunk);
#line 1804 "downloader.c"
}


static void __lambda47_ (Block74Data* _data74_, SoupSession* session, SoupMessage* msg) {
	BoxesDownloader* self;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data74_->self;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (session != NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data74_->_async_data_);
#line 1818 "downloader.c"
}


static void ___lambda47__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda47_ (self, session, msg);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block74_data_unref (self);
#line 1827 "downloader.c"
}


static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 1836 "downloader.c"
		goto _state_0;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 1840 "downloader.c"
		goto _state_1;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 1844 "downloader.c"
		goto _state_2;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 3:
#line 1848 "downloader.c"
		goto _state_3;
		default:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 1853 "downloader.c"
	}
	_state_0:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_ = g_slice_new0 (Block74Data);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->_ref_count_ = 1;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->self = g_object_ref (_data_->self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data74_->download);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->download = _data_->_tmp0_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->_async_data_ = _data_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data74_->download;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->uri;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = soup_message_new ("GET", _data_->_tmp2_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->msg = _data_->_tmp3_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = _data_->_data74_->msg;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = soup_message_get_address (_data_->_tmp4_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->address = _data_->_tmp6_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->address;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = soup_address_get_name (_data_->_tmp7_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = _data_->address;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = 0;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = soup_address_get_port (_data_->_tmp10_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = 0;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = (GNetworkAddress*) g_network_address_new (_data_->_tmp9_, (guint16) _data_->_tmp12_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->connectable = _data_->_tmp13_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = g_network_monitor_get_default ();
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = _g_object_ref0 (_data_->_tmp14_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->network_monitor = _data_->_tmp15_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = _data_->network_monitor;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->connectable;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_network_monitor_can_reach_async (_data_->_tmp17_, (GSocketConnectable*) _data_->_tmp18_, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 1954 "downloader.c"
	_state_1:
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = FALSE;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = g_network_monitor_can_reach_finish (_data_->_tmp17_, _data_->_res_, &_data_->_inner_error_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->_tmp19_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_inner_error_ != NULL) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block74_data_unref (_data_->_data74_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data74_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1982 "downloader.c"
		} else {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1986 "downloader.c"
		}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1992 "downloader.c"
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!_data_->_tmp16_) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp20_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp20_ = _data_->address;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp21_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp21_ = soup_address_get_name (_data_->_tmp20_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp22_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp22_ = _data_->_tmp21_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = _data_->address;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = soup_address_get_port (_data_->_tmp23_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to reach host '%s' on port '%d'", _data_->_tmp22_, _data_->_tmp25_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp26_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block74_data_unref (_data_->_data74_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data74_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2044 "downloader.c"
		} else {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2048 "downloader.c"
		}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2054 "downloader.c"
	}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->total_num_bytes = (gint64) 0;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = _data_->_data74_->msg;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp27_, "got-headers", (GCallback) ___lambda45__soup_message_got_headers, block74_data_ref (_data_->_data74_), (GClosureNotify) block74_data_unref, 0);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_->current_num_bytes = (gint64) 0;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = _data_->_data74_->msg;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp28_, "got-chunk", (GCallback) ___lambda46__soup_message_got_chunk, block74_data_ref (_data_->_data74_), (GClosureNotify) block74_data_unref, 0);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->self->priv->session;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = _data_->_data74_->msg;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = _g_object_ref0 (_data_->_tmp30_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_session_queue_message (_data_->_tmp29_, _data_->_tmp31_, ___lambda47__soup_session_callback, block74_data_ref (_data_->_data74_));
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 2;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2090 "downloader.c"
	_state_2:
	;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->_data74_->msg;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = 0U;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_get (_data_->_tmp32_, "status-code", &_data_->_tmp33_, NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = 0U;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp34_ != ((guint) SOUP_STATUS_OK)) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = _data_->_data74_->msg;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_get (_data_->_tmp35_, "reason-phrase", &_data_->_tmp36_, NULL);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->_tmp36_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = _data_->_tmp37_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _data_->_tmp38_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp38_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp40_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block74_data_unref (_data_->_data74_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data74_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2153 "downloader.c"
		} else {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2157 "downloader.c"
		}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2163 "downloader.c"
	}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp41_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp41_ = _data_->_data74_->download;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp42_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp42_ = _data_->_tmp41_->cached_file;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp43_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp43_ = _data_->_data74_->msg;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp44_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp44_ = _data_->_tmp43_->response_body;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45__length1 = 0;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45_ = _data_->_tmp44_->data;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45__length1 = (gint) _data_->_tmp44_->length;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 3;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_file_replace_contents_async (_data_->_tmp42_, _data_->_tmp45_, (gsize) _data_->_tmp45__length1, NULL, FALSE, 0, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2195 "downloader.c"
	_state_3:
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_file_replace_contents_finish (_data_->_tmp42_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_inner_error_ != NULL) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block74_data_unref (_data_->_data74_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data74_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2219 "downloader.c"
		} else {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2223 "downloader.c"
		}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2229 "downloader.c"
	}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->network_monitor);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->connectable);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->address);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block74_data_unref (_data_->_data74_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data74_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2245 "downloader.c"
	} else {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2249 "downloader.c"
	}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2255 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_data_free (gpointer _data) {
	BoxesDownloaderFetchOsLogoData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderFetchOsLogoData, _data_);
#line 2268 "downloader.c"
}


void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
	GtkImage* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	OsinfoOs* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderFetchOsLogoData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_downloader_fetch_os_logo);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_fetch_os_logo_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = image;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->image = _tmp1_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = os;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->os = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = size;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->size = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2307 "downloader.c"
}


void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2315 "downloader.c"
}


static void _vala_array_add19 (gchar*** array, int* length, int* size, gchar* value) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if ((*length) == (*size)) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 2326 "downloader.c"
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(*array)[(*length)++] = value;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(*array)[*length] = NULL;
#line 2332 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2346 "downloader.c"
}


static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 2355 "downloader.c"
		goto _state_0;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 2359 "downloader.c"
		goto _state_1;
		default:
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2364 "downloader.c"
	}
	_state_0:
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->os;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = boxes_downloader_fetch_os_logo_url (_data_->_tmp0_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->logo_url = _data_->_tmp1_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->logo_url;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp2_ == NULL) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2389 "downloader.c"
		} else {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2393 "downloader.c"
		}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2399 "downloader.c"
	}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->os;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp3_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->logo_url;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:147: %s has logo '%s'.", _data_->_tmp5_, _data_->_tmp6_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->logo_url;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_file_new_for_uri (_data_->_tmp7_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _data_->_tmp8_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->remote_file;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = g_file_get_basename (_data_->_tmp9_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = boxes_get_system_logo_cache (_data_->_tmp11_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp11_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->system_cached_path = _data_->_tmp13_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->remote_file;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = g_file_get_basename (_data_->_tmp14_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = boxes_get_logo_cache (_data_->_tmp16_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp16_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp18_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->cached_path;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_new0 (gchar*, 1 + 1);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_[0] = _data_->_tmp20_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = 0;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_cached_paths_size_ = 0;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _data_->_tmp21_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = 1;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_cached_paths_size_ = _data_->cached_paths_length1;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = NULL;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->system_cached_path;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp22_ != NULL) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23__length1 = 0;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = _data_->cached_paths;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23__length1 = _data_->cached_paths_length1;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = _data_->system_cached_path;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = g_strdup (_data_->_tmp24_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_vala_array_add19 (&_data_->cached_paths, &_data_->cached_paths_length1, &_data_->_cached_paths_size_, _data_->_tmp25_);
#line 2525 "downloader.c"
	}
	{
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = boxes_downloader_get_instance ();
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = _data_->remote_file;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29__length1 = 0;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29_ = _data_->cached_paths;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29__length1 = _data_->cached_paths_length1;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = boxes_activity_progress_new ();
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = _data_->_tmp30_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_download (_data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_, _data_->_tmp29__length1, _data_->_tmp31_, boxes_downloader_fetch_os_logo_ready, _data_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2562 "downloader.c"
		_state_1:
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp32_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp32_ = boxes_downloader_download_finish (_data_->_tmp27_, _data_->_res_, &_data_->_inner_error_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp33_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp31_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp27_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp33_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_inner_error_ != NULL) {
#line 2580 "downloader.c"
			goto __catch120_g_error;
		}
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp34_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp34_ = _data_->cached_file;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = g_file_get_path (_data_->_tmp34_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = 0;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->size;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = 0;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = _data_->size;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = gdk_pixbuf_new_from_file_at_size (_data_->_tmp36_, _data_->_tmp37_, _data_->_tmp38_, &_data_->_inner_error_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp36_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->pixbuf = _data_->_tmp40_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_inner_error_ != NULL) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 2619 "downloader.c"
			goto __catch120_g_error;
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = _data_->image;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = _data_->pixbuf;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		gtk_image_set_from_pixbuf (_data_->_tmp41_, _data_->_tmp42_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->pixbuf);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 2636 "downloader.c"
	}
	goto __finally120;
	__catch120_g_error:
	{
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = _data_->logo_url;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = _data_->_error_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = _data_->_tmp44_->message;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_warning ("downloader.vala:162: Error loading logo file '%s': %s", _data_->_tmp43_, _data_->_tmp45_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 2661 "downloader.c"
	}
	__finally120:
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_inner_error_ != NULL) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->system_cached_path);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->remote_file);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_clear_error (&_data_->_inner_error_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2682 "downloader.c"
	}
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->system_cached_path);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->logo_url);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2698 "downloader.c"
	} else {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2702 "downloader.c"
	}
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2708 "downloader.c"
}


static void boxes_downloader_await_download_data_free (gpointer _data) {
	BoxesDownloaderAwaitDownloadData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderAwaitDownloadData, _data_);
#line 2725 "downloader.c"
}


static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownload* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
	BoxesActivityProgress* _tmp6_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderAwaitDownloadData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_await_download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_await_download_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_path;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = progress;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp6_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 2774 "downloader.c"
}


static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderAwaitDownloadData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return NULL;
#line 2785 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 2795 "downloader.c"
}


static Block75Data* block75_data_ref (Block75Data* _data75_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data75_->_ref_count_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return _data75_;
#line 2804 "downloader.c"
}


static void block75_data_unref (void * _userdata_) {
	Block75Data* _data75_;
	_data75_ = (Block75Data*) _userdata_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data75_->_ref_count_)) {
#line 2813 "downloader.c"
		BoxesDownloader* self;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		self = _data75_->self;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		(_data75_->callback_target_destroy_notify == NULL) ? NULL : (_data75_->callback_target_destroy_notify (_data75_->callback_target), NULL);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data75_->callback = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data75_->callback_target = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data75_->callback_target_destroy_notify = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data75_->download_error);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data75_->downloaded_file);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data75_->download);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_slice_free (Block75Data, _data75_);
#line 2835 "downloader.c"
	}
}


static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self) {
	gboolean result;
	result = boxes_downloader_await_download_co (self);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 2845 "downloader.c"
}


static void __lambda43_ (Block75Data* _data75_, BoxesDownloader* downloader, BoxesDownload* downloaded) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	BoxesDownload* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data75_->self;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloaded != NULL);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = downloaded;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data75_->download;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 2876 "downloader.c"
	}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = downloaded;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _tmp4_->cached_file;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data75_->downloaded_file);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data75_->downloaded_file = _tmp6_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data75_->callback (_data75_->callback_target);
#line 2890 "downloader.c"
}


static void ___lambda43__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda43_ (self, _sender, download);
#line 2897 "downloader.c"
}


static void __lambda44_ (Block75Data* _data75_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GError* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data75_->self;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (failed_download != NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = failed_download;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data75_->download;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 2927 "downloader.c"
	}
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = _error_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_error_copy0 (_tmp4_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_error_free0 (_data75_->download_error);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data75_->download_error = _tmp5_;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data75_->callback (_data75_->callback_target);
#line 2939 "downloader.c"
}


static void ___lambda44__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self) {
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda44_ (self, _sender, download, _error_);
#line 2946 "downloader.c"
}


static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 2960 "downloader.c"
}


static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 2969 "downloader.c"
		goto _state_0;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 2973 "downloader.c"
		goto _state_1;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 2977 "downloader.c"
		goto _state_2;
		default:
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2982 "downloader.c"
	}
	_state_0:
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_ = g_slice_new0 (Block75Data);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->_ref_count_ = 1;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->self = g_object_ref (_data_->self);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data75_->download);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->download = _data_->_tmp0_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->_async_data_ = _data_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->downloaded_file = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->download_error = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data75_->download;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->progress;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->progress;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_tmp2_, "progress", (GObject*) _data_->_tmp3_, "progress", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->callback = _boxes_downloader_await_download_co_gsource_func;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->callback_target = _data_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_->callback_target_destroy_notify = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = 0UL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_signal_connect_data (_data_->self, "downloaded", (GCallback) ___lambda43__boxes_downloader_downloaded, block75_data_ref (_data_->_data75_), (GClosureNotify) block75_data_unref, 0);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->downloaded_id = _data_->_tmp4_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = 0UL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = g_signal_connect_data (_data_->self, "download-failed", (GCallback) ___lambda44__boxes_downloader_download_failed, block75_data_ref (_data_->_data75_), (GClosureNotify) block75_data_unref, 0);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->downloaded_failed_id = _data_->_tmp5_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->_data75_->download;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_->uri;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:189: '%s' already being downloaded. Waiting for downlo" \
"ad to complete..", _data_->_tmp7_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3051 "downloader.c"
	_state_1:
	;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = _data_->_data75_->download;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->_tmp8_->uri;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:191: Finished waiting for '%s' to download.", _data_->_tmp9_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_id);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_failed_id);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_data75_->download_error != NULL) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _g_error_copy0 (_data_->_data75_->download_error);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp10_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block75_data_unref (_data_->_data75_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data75_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3088 "downloader.c"
		} else {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3092 "downloader.c"
		}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3098 "downloader.c"
	}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = g_file_get_path (_data_->_data75_->downloaded_file);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->cached_path;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = g_strcmp0 (_data_->_tmp12_, _data_->_tmp13_) != 0;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp12_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp14_) {
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->cached_path;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp16_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp16_ = g_file_new_for_path (_data_->_tmp15_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp16_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp17_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp17_ = _data_->cached_file;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 2;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_file_copy_async (_data_->_data75_->downloaded_file, _data_->_tmp17_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_downloader_await_download_ready, _data_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3142 "downloader.c"
		_state_2:
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_file_copy_finish (_data_->_data75_->downloaded_file, _data_->_res_, &_data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_inner_error_ != NULL) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_error_free (_data_->_inner_error_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			block75_data_unref (_data_->_data75_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_data75_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_state_ == 0) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3162 "downloader.c"
			} else {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3166 "downloader.c"
			}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 3172 "downloader.c"
		}
	} else {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp18_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp18_ = _g_object_ref0 (_data_->_data75_->downloaded_file);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp18_;
#line 3183 "downloader.c"
	}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block75_data_unref (_data_->_data75_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3195 "downloader.c"
	} else {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3199 "downloader.c"
	}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block75_data_unref (_data_->_data75_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data75_ = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3215 "downloader.c"
	} else {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3219 "downloader.c"
	}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3225 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 2);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3244 "downloader.c"
	} else {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3250 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD) (marshal_data ? marshal_data : cc->callback);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), data2);
#line 3256 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 3);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3275 "downloader.c"
	} else {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3281 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (marshal_data ? marshal_data : cc->callback);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), g_value_get_pointer (param_values + 2), data2);
#line 3287 "downloader.c"
}


static void boxes_downloader_class_init (BoxesDownloaderClass * klass) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_type_class_add_private (klass, sizeof (BoxesDownloaderPrivate));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_downloader_finalize;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_new ("downloaded", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD, G_TYPE_NONE, 1, BOXES_TYPE_DOWNLOAD);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_new ("download_failed", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER, G_TYPE_NONE, 2, BOXES_TYPE_DOWNLOAD, G_TYPE_POINTER);
#line 3302 "downloader.c"
}


static void boxes_downloader_instance_init (BoxesDownloader * self) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv = BOXES_DOWNLOADER_GET_PRIVATE (self);
#line 3309 "downloader.c"
}


static void boxes_downloader_finalize (GObject* obj) {
	BoxesDownloader * self;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOADER, BoxesDownloader);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (boxes_downloader_parent_class)->finalize (obj);
#line 3323 "downloader.c"
}


GType boxes_downloader_get_type (void) {
	static volatile gsize boxes_downloader_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_downloader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_downloader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownloader), 0, (GInstanceInitFunc) boxes_downloader_instance_init, NULL };
		GType boxes_downloader_type_id;
		boxes_downloader_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDownloader", &g_define_type_info, 0);
		g_once_init_leave (&boxes_downloader_type_id__volatile, boxes_downloader_type_id);
	}
	return boxes_downloader_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3342 "downloader.c"
		int i;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3350 "downloader.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 3362 "downloader.c"
}



